@@ -156,17 +156,29 @@ $index must be less than the length of $list. Otherwise an exception is thrown.
 
 =head2 replace
 
-C<method replace : void ($index : int, $remove_length : int, $replace : string[]);>
+C<method replace : void ($offset : int, $remove_length : int, $replace : string[] = undef);>
 
-Replaces the elements of the range specified by $index and $length with $replace array.
+Same as L</"splice"> method, but the return vlaue is not returned.
 
 Exceptions:
 
-$index must be greater than or equal to 0. Otherwise an exception is thrown.
+Exceptions thrown by L</"splice> method could be thrown.
+
+=head2 splice
+
+C<method splice : string[] ($offset : int, $remove_length : int, $replace : string[] = undef);>
+
+Replaces the elements of the range specified by $offset and $length with $replace array, and returns removed elements creating a new array.
+
+If $replace is not defined, the replacemnet is not performed.
+
+Exceptions:
+
+$offset must be greater than or equal to 0. Otherwise an exception is thrown.
 
 $remove_length must be greater than or equal to 0. Otherwise an exception is thrown.
 
-$index + $removing length must be less than or equal to the length of $list.
+$offset + $removing length must be less than or equal to the length of $list. Otherwise an exception is thrown.
 
 =head2 set
 
@@ -202,6 +214,40 @@ C<method unshift : void ($element : string);>
 
 Inserts an $element at the beginning of the list.
 
+=head2 clone
+
+C<method clone : L<StringList|SPVM::StringList> ();>
+
+Clones this instance and returns it.
+
+Each element is cloned by C<copy> operator.
+
+=head2 push_array
+
+C<method push_array : void ($elements : byte[]);>
+
+Adds the elements $elements after the end of this list.
+
+This method calls L</"push"> method internally.
+
+Exceptions:
+
+The elements $elements must be defined.
+
+Exceptions thrown by L</"push"> method could be thrown.
+
+=head2 unshift_array
+
+C<method unshift_array : void ($elements : byte[]);>
+
+Inserts the elements $elements at the beginning of the list.
+
+Exceptions:
+
+The elements $elements must be defined.
+
+Exceptions thrown by L</"unshift"> method could be thrown.
+
 =head1 Copyright & License
 
 Copyright (c) 2023 Yuki Kimoto
